<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>KeePassX 정보</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassX는 GNU General Public License(GPL) 버전 2 혹은 버전 3(선택적)으로 배포됩니다.</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>리비전</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>사용:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>자동 입력 - KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>창 제목과 일치하는 항목을 찾을 수 없습니다:</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>시퀀스</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>기본 시퀀스</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>자동 입력 - KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>자동으로 입력할 항목 선택:</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>암호</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>암호 입력:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>암호 확인:</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>키 파일</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>찾아보기</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>만들기</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>키 파일</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>키 파일 만들기...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>키 파일을 만들 수 없습니다: </translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>키 파일 선택</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>질문</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>빈 문자열을 암호로 사용하시겠습니까?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>다른 암호를 입력하였습니다.</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>키 파일을 설정할 수 없음</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>%1을(를) 키 파일로 설정할 수 없습니다: %2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>마스터 키 입력</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>키 파일:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>찾아보기</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>데이터베이스를 열 수 없습니다.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>키 파일을 열 수 없음</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>키 파일</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>키 파일 선택</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>데이터베이스 복구</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>키 파일을 열 수 없음</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>데이터베이스를 열었습니다. 할 일이 없습니다.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>데이터베이스를 열 수 없습니다.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>성공</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>데이터베이스를 복구했습니다
이제 저장할 수 있습니다.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>데이터베이스를 복구할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>데이터베이스 이름:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>데이터베이스 설명:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>변환 횟수:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>기본 사용자 이름:</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>휴지통 사용:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>벤치마크</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>최대 과거 항목 수:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>최대 과거 항목 크기:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>루트</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 데이터베이스</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>데이터베이스 열기</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>파일을 찾을 수 없습니다!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>KeePass 1 데이터베이스 열기</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 데이터베이스</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>모든 파일 (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>닫기 확인?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>변경 사항 저장 확인?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot;이(가) 변경되었습니다. 저장하시겠습니까?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>데이터베이스에 쓸 수 없습니다.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>다른 이름으로 데이터베이스 저장</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>새 데이터베이스</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>잠김</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>열려고 하는 데이터베이스를 다른 KeePassX 인스턴스에서 잠갔습니다.
그래도 여시겠습니까? 읽기 전용으로 열 수도 있습니다.</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>데이터베이스 잠금</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>데이터베이스를 편집하고 있어서 잠글 수 없습니다.
취소를 눌러서 변경 사항을 저장하거나 무시하십시오.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>이 데이터베이스가 저장되지 않았습니다.
데이터베이스를 저장하거나 잠금을 풀 수 있습니다.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>데이터베이스가 수정되었습니다.
잠그기 전에 데이터베이스를 저장하시겠습니까?
저장하지 않은 변경 사항은 손실됩니다.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot;이(가) 현재 편집 모드입니다.
변경 사항을 무시하고 닫으시겠습니까?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>데이터베이스를 CSV 파일로 내보내기</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV 파일</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>CSV 파일에 기록할 수 없습니다.</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>저장하려고 하는 데이터베이스를 다른 KeePassX 인스턴스에서 잠갔습니다.
그래도 저장하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>마스터 키 변경</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>항목을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>정말 항목 &quot;%1&quot;을(를) 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>항목을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>정말 항목 %1개를 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>항목을 휴지통으로 이동하시겠습니까?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>항목 %n개를 휴지통으로 이동하시겠습니까?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>그룹을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>정말 그룹 &quot;%1&quot;을(를) 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>현재 그룹</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없음</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>항목</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>고급</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>아이콘</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>자동 입력</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <source>History</source>
        <translation>과거 기록</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>항목 과거 기록</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>항목 추가</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>항목 편집</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>다른 암호를 입력하였습니다.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>새 속성</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>파일 선택</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>파일을 열 수 없습니다</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>첨부 항목 저장</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>첨부 항목을 저장할 수 없습니다:</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>내일</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n주</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n개월</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1년</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>추가 속성</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>첨부</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>이 항목 자동 입력 사용</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>그룹의 기본 자동 입력 시퀀스 사용</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>사용자 정의 자동 입력 시퀀스 사용:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>창 제목:</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>기본 시퀀스 사용</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>사용자 정의 시퀀스 설정:</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>보이기</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>복원</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>모두 삭제</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>제목:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>사용자 이름:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>암호 확인:</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>생성</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>만료 기간</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>사전 설정</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>메모:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>아이콘</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>그룹 추가</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>그룹 편집</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>활성화</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>비활성화</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>부모 그룹에서 상속(%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>메모</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>만료 기간</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>자동 입력</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>부모 그룹의 기본 자동 입력 시퀀스 사용</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>기본 자동 입력 시퀀스 설정</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>기본 아이콘 사용</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>사용자 정의 아이콘 사용</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>사용자 정의 아이콘 추가</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>사용자 정의 아이콘 삭제</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>그림</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>그림 선택</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>아이콘을 삭제할 수 없습니다!</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>아이콘을 삭제할 수 없습니다. 항목 %n개에서 사용 중입니다.</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>만든 날짜:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>수정한 날짜:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>접근한 날짜:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>UUID:</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>마지막 수정</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>휴지통</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>KeePass1 데이터베이스 가져오기</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>데이터베이스를 열 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>키 파일을 읽을 수 없습니다.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>KeePass 데이터베이스가 아닙니다.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>지원하지 않는 암호화 알고리즘입니다.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>지원하지 않는 KeePass 데이터베이스 버전입니다.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>루트</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없음</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>KeePass 데이터베이스가 아닙니다.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>지원하지 않는 KeePass 데이터베이스 버전입니다.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>키가 잘못되었거나 데이터베이스가 손상되었습니다.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없습니다</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>선택한 파일은 KeePass 1 데이터베이스(.kdb)입니다.

데이터베이스 &gt; &apos;KeePass 1 데이터베이스 가져오기&apos; 항목을 선택해서 변환해야 합니다.
변환은 한 방향으로만 이루어지며, 가져온 데이터베이스는 KeePassX 0.4 버전으로 더 이상 열 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>암호화 함수를 시험하는 중 오류가 발생하였습니다.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - 오류</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>데이터베이스</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>최근 데이터베이스</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>항목</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>클립보드에 속성 복사</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>그룹</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>끝내기</translation>
    </message>
    <message>
        <source>About</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>데이터베이스 열기</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>데이터베이스 저장</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>데이터베이스 닫기</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>새 데이터베이스</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>새 항목 추가</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>항목 보기/편집</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>항목 삭제</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>새 그룹 추가</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>그룹 편집</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>그룹 삭제</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>다른 이름으로 데이터베이스 저장</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>마스터 키 변경</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>데이터베이스 설정</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>KeePass 1 데이터베이스 가져오기</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>항목 복제</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>클립보드에 사용자 이름 복사</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>클립보드에 암호 복사</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>자동 입력 실행</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>URL 열기</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>데이터베이스 잠금</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>메모</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>도구 모음 보이기</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>읽기 전용</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>창 전환</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>도구</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>사용자 이름 복사</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>암호 복사</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>CSV 파일로 내보내기</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>데이터베이스 복구</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 데이터베이스</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>복구한 데이터베이스 저장</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>데이터베이스에 쓸 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>길이:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>문자 종류</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>대문자</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>소문자</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>숫자</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>특수 문자</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>비슷하게 생긴 문자 제외</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>모든 그룹에서 최소 1글자 이상 포함</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>사용</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>버전 정보를 표시합니다.</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>이 도움말을 표시합니다.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>알 수 없는 옵션 &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>알 수 없는 옵션 &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; 다음에 값이 없습니다.</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; 다음에 예상하지 못한 값이 왔습니다.</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[옵션]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>사용 방법: %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>옵션:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>인자:</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>존재하는 파일 %1에 기록할 수 없음</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>프로그램에서 쓰기 작업 취소함</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>일부분만 기록되었습니다. 파티션이 가득 찼습니까?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>압축 중 내부 zlib 오류 발생:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>장치에 기록하는 중 오류 발생:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>장치를 여는 중 오류 발생:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>장치에서 읽는 중 오류 발생:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>압축 푸는 중 내부 zlib 오류 발생:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>이 버전의 zlib에서 gzip 형식을 지원하지 않습니다.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>내부 zlib 오류: </translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>찾기:</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>대소문자 구분</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>현재 그룹</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>루트 그룹</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>프로그램 설정</translation>
    </message>
    <message>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>보안</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>마지막 데이터베이스 기억</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>시작할 때 이전 데이터베이스 열기</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>끝낼 때 자동 저장</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>항목을 변경할 때 자동 저장</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>클립보드에 복사할 때 최소화</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>항목을 만들 때 그룹 아이콘 사용</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>전역 자동 입력 단축키</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>전역 자동 입력 시 항목 제목과 일치하는 창 찾기</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>언어</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>시스템 트레이 아이콘 표시</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>시스템 트레이로 최소화</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>마지막 키 파일 기억</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>다음 시간 이후 클립보드 비우기</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>초</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>다음 시간 동안 활동이 없을 때 데이터베이스 잠금</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>기본값으로 암호를 평문으로 표시</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>자동으로 입력하기 전에 항상 묻기</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>데이터베이스 잠금 해제</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>환영합니다!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX - 크로스 플랫폼 암호 관리자</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>열 암호 데이터베이스 파일 이름 (*.kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>사용자 정의 설정 파일 경로</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>데이터베이스 키 파일</translation>
    </message>
</context>
</TS>